@@ -5,7 +5,7 @@ except Exception:
     METRICS_ENABLED = False
 
 
-class _DummyMetricType(object):
+class _DummyMetricType:
     """
     Emulates a yelp_meteorite counter, gauge, or timer
     """
@@ -19,7 +19,7 @@ class _DummyMetricType(object):
 
 
 _dummy_metric = _DummyMetricType()
-_registered_metrics = {}
+_registered_metrics: dict = {}
 
 
 def create_counter(name, dimensions={}):
