@@ -27,6 +27,7 @@ from task_processing.plugins.kubernetes.types import PodEvent
 from task_processing.plugins.kubernetes.utils import get_kubernetes_env_vars
 from task_processing.plugins.kubernetes.utils import get_kubernetes_volume_mounts
 from task_processing.plugins.kubernetes.utils import get_pod_volumes
+from task_processing.plugins.kubernetes.utils import get_sanitised_kubernetes_name
 from task_processing.plugins.kubernetes.utils import get_security_context_for_capabilities
 
 logger = logging.getLogger(__name__)
@@ -324,7 +325,7 @@ class KubernetesPodExecutor(TaskExecutor):
         try:
             container = V1Container(
                 image=task_config.image,
-                name=task_config.name,
+                name=get_sanitised_kubernetes_name(task_config.name, replace_dots=True),
                 command=["/bin/sh", "-c"],
                 args=[task_config.command],
                 security_context=get_security_context_for_capabilities(
@@ -338,7 +339,10 @@ class KubernetesPodExecutor(TaskExecutor):
                         "ephemeral-storage": f"{task_config.disk}Mi",
                     }
                 ),
-                env=get_kubernetes_env_vars(task_config.environment),
+                env=get_kubernetes_env_vars(
+                    task_config.environment,
+                    task_config.secret_environment,
+                ),
                 volume_mounts=get_kubernetes_volume_mounts(task_config.volumes)
             )
             pod = V1Pod(
