@@ -1,22 +1,24 @@
 import hashlib
 import logging
-import re
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import TYPE_CHECKING
 
 from kubernetes.client import V1Capabilities
 from kubernetes.client import V1EnvVar
+from kubernetes.client import V1EnvVarSource
 from kubernetes.client import V1HostPathVolumeSource
+from kubernetes.client import V1SecretKeySelector
 from kubernetes.client import V1SecurityContext
 from kubernetes.client import V1Volume
 from kubernetes.client import V1VolumeMount
 from pyrsistent.typing import PMap
 from pyrsistent.typing import PVector
 
-from task_processing.plugins.kubernetes.types import DockerVolume
-
-SECRET_VALUE_REGEX = re.compile(r"^(SHARED_)?SECRET\([A-Za-z0-9_-]*\)$")
+if TYPE_CHECKING:
+    from task_processing.plugins.kubernetes.types import DockerVolume
+    from task_processing.plugins.kubernetes.types import SecretEnvSource
 
 logger = logging.getLogger(__name__)
 
@@ -44,15 +46,9 @@ def get_security_context_for_capabilities(
     return None
 
 
-def is_secret_env_var(value: str) -> bool:
-    """
-    Given the value of an environment variable, return if that environment variable represents
-    a secret.
-    """
-    return SECRET_VALUE_REGEX.match(value) is not None
-
-
-def get_kubernetes_env_vars(environment: PMap[str, str]) -> List[V1EnvVar]:
+def get_kubernetes_env_vars(
+    environment: PMap[str, str], secret_environment: PMap[str, 'SecretEnvSource'],
+) -> List[V1EnvVar]:
     """
     Given a dict of environment variables, transform them into the corresponding Kubernetes
     representation. This function will replace any secret placeholders with the value of
@@ -60,29 +56,37 @@ def get_kubernetes_env_vars(environment: PMap[str, str]) -> List[V1EnvVar]:
     """
     env_vars = [
         V1EnvVar(name=key, value=value) for key, value
-        in environment.items()
-        if not is_secret_env_var(value)
+        in environment.items() if key not in secret_environment.keys()
     ]
 
-    # TODO(TASKPROC-249): we'll want to do what PaaSTA does for grabbing the actual secrets
-    # once we're syncing these to the tron namespace and not just dump these in as-is
-    # XXX: we should document how we're expecting secrets to be formatted and how we're expecting
-    # to be able to find them in k8s for any readers/users outside of Yelp
     secret_env_vars = [
-        V1EnvVar(name=key, value=value) for key, value
-        in environment.items()
-        if is_secret_env_var(value)
+        V1EnvVar(name=key, value_from=V1EnvVarSource(
+            secret_key_ref=V1SecretKeySelector(
+                name=value["secret"],
+                key=value["key"],
+                optional=False,
+            ),
+        ),
+        )
+        for key, value
+        in secret_environment.items()
     ]
+
     return env_vars + secret_env_vars
 
 
-def get_sanitised_kubernetes_name(name: str) -> str:
+def get_sanitised_kubernetes_name(name: str, replace_dots: bool = False) -> str:
     """
     Helper to ensure that any names given to Kubernetes objects follow our conventions
+
+    replace_dots is an optional parameter for objects such as Containers that cannot contain `.`s in
+    their names (in contrast to objects such as Pods that can)
     """
     name = name.replace("_", "--")
     if name.startswith("--"):
         name = name.replace("--", "underscore-", 1)
+    if replace_dots:
+        name = name.replace(".", "dot-")
     return name.lower()
 
 
@@ -105,7 +109,7 @@ def get_sanitised_volume_name(volume_name: str, length_limit: int = 0) -> str:
     return sanitised_name
 
 
-def get_kubernetes_volume_mounts(volumes: PVector[DockerVolume]) -> List[V1VolumeMount]:
+def get_kubernetes_volume_mounts(volumes: PVector['DockerVolume']) -> List[V1VolumeMount]:
     """
     Given a list of volume mounts, return a list corresponding to the Kubernetes objects
     representing these mounts.
@@ -123,12 +127,12 @@ def get_kubernetes_volume_mounts(volumes: PVector[DockerVolume]) -> List[V1Volum
     ]
 
 
-def get_pod_volumes(volumes: PVector[DockerVolume]) -> List[V1Volume]:
+def get_pod_volumes(volumes: PVector['DockerVolume']) -> List[V1Volume]:
     """
     Given a list of volume mounts, return a list corresponding to the Kubernetes objects needed to
     tie the mounts to a Pod.
     """
-    unique_volumes: Dict[str, DockerVolume] = {
+    unique_volumes: Dict[str, 'DockerVolume'] = {
         get_sanitised_volume_name(f"host--{volume['host_path']}", length_limit=63): volume
         for volume in volumes
     }
